@@ -30,6 +30,15 @@ if not PY2:
     from string import ascii_lowercase
     import urllib.parse as urllib
     import urllib.parse as urlparse
+
+    console_encoding = sys.__stdout__.encoding
+
+    def console_to_str(s):
+        """ From pypa/pip project, pip.backwardwardcompat. License MIT. """
+        try:
+            return s.decode(console_encoding)
+        except UnicodeDecodeError:
+            return s.decode('utf_8')
 else:
     text_type = unicode
     string_types = (str, unicode)
@@ -55,5 +64,8 @@ else:
     from string import lower as ascii_lowercase
     import urlparse
 
+    def console_to_str(s):
+        return s.decode('utf_8')
+
 
 number_types = integer_types + (float,)
