@@ -8,20 +8,25 @@ tmuxp.cli
 :license: BSD, see LICENSE for details
 
 """
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import os
 import sys
 import argparse
-import argcomplete
+import re
 import logging
-import kaptan
-from . import log, util, exc, WorkspaceBuilder, Server, config
-from .util import ascii_lowercase, input
-from .workspacebuilder import freeze
+
 from distutils.util import strtobool
 
+import argcomplete
+import kaptan
+
+from . import log, util, exc, WorkspaceBuilder, Server, config
+from ._compat import ascii_lowercase, input
+from .workspacebuilder import freeze
+
 
-import re
 VERSIONFILE = os.path.join(
     os.path.abspath(os.path.dirname(__file__)), '__init__.py'
 )
@@ -332,9 +337,16 @@ def command_freeze(args):
         colors=args.colors
     )
 
-    session = t.findWhere({
-        'session_name': ctext
-    })
+    try:
+        session = t.findWhere({
+            'session_name': ctext
+        })
+
+        if not session:
+            raise exc.TmuxpException('Session not found.')
+    except exc.TmuxpException as e:
+        print(e)
+        return
 
     sconf = freeze(session)
     configparser = kaptan.Kaptan()
@@ -393,49 +405,28 @@ def command_freeze(args):
 
 def command_load(args):
     """Load a session from a tmuxp session file."""
-    if args.list:
-        startup(config_dir)
-        configs_in_user = config.in_dir(config_dir)
-        configs_in_cwd = config.in_cwd()
 
-        sys.exit()
+    if isinstance(args.config, list):
+        args.config = ' '.join(args.config)
 
-        output = ''
-
-        if not configs_in_user:
-            output += '# %s: \n\tNone found.\n' % config_dir
+    if '.' == args.config:
+        if config.in_cwd():
+            configfile = config.in_cwd()[0]
         else:
-            output += '# %s: \n\t%s\n' % (
-                config_dir, ', '.join(configs_in_user)
-            )
+            sys.exit('No tmuxp configs found in current directory.')
+    else:
+        configfile = args.config
 
-        if configs_in_cwd:
-            output += '# current directory:\n\t%s' % (
-                ', '.join(configs_in_cwd)
-            )
+    file_user = os.path.join(config_dir, configfile)
+    file_cwd = os.path.join(cwd_dir, configfile)
 
-        print(output)
-        return
-
-    elif args.config:
-        if '.' == args.config:
-            if config.in_cwd():
-                configfile = config.in_cwd()[0]
-                print(configfile)
-            else:
-                sys.exit('No tmuxp configs found in current directory.')
-        else:
-            configfile = args.config
-        file_user = os.path.join(config_dir, configfile)
-        file_cwd = os.path.join(cwd_dir, configfile)
-
-        if os.path.exists(file_cwd) and os.path.isfile(file_cwd):
-            print('load %s' % file_cwd)
-            load_workspace(file_cwd, args)
-        elif os.path.exists(file_user) and os.path.isfile(file_user):
-            load_workspace(file_user, args)
-        else:
-            logger.error('%s not found.' % configfile)
+    if os.path.exists(file_cwd) and os.path.isfile(file_cwd):
+        print('load %s' % file_cwd)
+        load_workspace(file_cwd, args)
+    elif os.path.exists(file_user) and os.path.isfile(file_user):
+        load_workspace(file_user, args)
+    else:
+        logger.error('%s not found.' % configfile)
 
 
 def command_import_teamocil(args):
@@ -847,16 +838,10 @@ def get_parser():
              'already exists, offer to attach instead.'
     )
 
-    loadgroup = load.add_mutually_exclusive_group(required=True)
-    loadgroup.add_argument(
-        '--list', dest='list', action='store_true',
-        help='List config files available',
-    )
-
-    loadgroup.add_argument(
+    load.add_argument(
         dest='config',
         type=str,
-        nargs='?',
+        nargs='+',
         help='List config available in working directory and config folder.'
     ).completer = ConfigFileCompleter(
         allowednames=('.yaml', '.json'), directories=False
@@ -972,19 +957,22 @@ def main():
         colors=args.colors
     )
 
-    if args.callback is command_load:
-        command_load(args)
-    elif args.callback is command_convert:
-        command_convert(args)
-    elif args.callback is command_import_teamocil:
-        command_import_teamocil(args)
-    elif args.callback is command_import_tmuxinator:
-        command_import_tmuxinator(args)
-    elif args.callback is command_freeze:
-        command_freeze(args)
-    elif args.callback is command_attach_session:
-        command_attach_session(args)
-    elif args.callback is command_kill_session:
-        command_kill_session(args)
-    else:
-        parser.print_help()
+    try:
+        if args.callback is command_load:
+            command_load(args)
+        elif args.callback is command_convert:
+            command_convert(args)
+        elif args.callback is command_import_teamocil:
+            command_import_teamocil(args)
+        elif args.callback is command_import_tmuxinator:
+            command_import_tmuxinator(args)
+        elif args.callback is command_freeze:
+            command_freeze(args)
+        elif args.callback is command_attach_session:
+            command_attach_session(args)
+        elif args.callback is command_kill_session:
+            command_kill_session(args)
+        else:
+            parser.print_help()
+    except KeyboardInterrupt:
+        pass
