@@ -1,15 +1,20 @@
 # -*- coding: utf8 - *-
-"""
-    tmuxp.formats
-    ~~~~~~~~~~~~~
+"""Format variables for tmux objects.
 
-    .. _For reference:
-       http://sourceforge.net/p/tmux/tmux-code/ci/master/tree/format.c
+tmuxp.formats
+~~~~~~~~~~~~~
+
+For reference: http://sourceforge.net/p/tmux/tmux-code/ci/master/tree/format.c
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
 
-    :copyright: Copyright 2013 Tony Narlock.
-    :license: BSD, see LICENSE for details
 """
 
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
+
+
 SESSION_FORMATS = [
     'session_name',
     'session_windows',
