@@ -8,10 +8,12 @@ tmuxp.log
 :license: BSD, see LICENSE for details
 
 """
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
-from __future__ import absolute_import, division, print_function, with_statement
 import logging
 import time
+
 from ._vendor.colorama import init
 from ._vendor.colorama import Fore, Back, Style
 
@@ -32,12 +34,24 @@ def default_log_template(self, record):
 
     """
 
-    tpl = ''
-    tpl += Style.RESET_ALL
-    tpl += LEVEL_COLORS.get(record.levelname) + Style.BRIGHT + '(%(levelname)s)' + Style.RESET_ALL + ' '
-    tpl += '[' + Fore.BLACK + Style.DIM + Style.BRIGHT + '%(asctime)s' + Fore.RESET + Style.RESET_ALL + ']'
-    tpl += ' ' + Fore.WHITE + Style.DIM + Style.BRIGHT + '%(name)s' + Fore.RESET + Style.RESET_ALL + ' '
-    tpl += Style.RESET_ALL
+    reset = Style.RESET_ALL
+    levelname = (
+        LEVEL_COLORS.get(record.levelname) + Style.BRIGHT +
+        '(%(levelname)s)'
+        + Style.RESET_ALL + ' '
+    )
+    asctime = (
+        '[' + Fore.BLACK + Style.DIM + Style.BRIGHT +
+        '%(asctime)s'
+        + Fore.RESET + Style.RESET_ALL + ']'
+    )
+    name = (
+        ' ' + Fore.WHITE + Style.DIM + Style.BRIGHT +
+        '%(name)s'
+        + Fore.RESET + Style.RESET_ALL + ' '
+    )
+
+    tpl = reset + levelname + asctime + name + reset
 
     return tpl
 
@@ -56,7 +70,9 @@ class LogFormatter(logging.Formatter):
             record.message = "Bad message (%r): %r" % (e, record.__dict__)
 
         date_format = '%H:%m:%S'
-        record.asctime = time.strftime(date_format, self.converter(record.created))
+        record.asctime = time.strftime(
+            date_format, self.converter(record.created)
+        )
 
         prefix = self.template(record) % record.__dict__
 
@@ -72,14 +88,32 @@ def debug_log_template(self, record):
 
     """
 
-    tpl = ''
-    tpl += Style.RESET_ALL
-    tpl += LEVEL_COLORS.get(record.levelname) + Style.BRIGHT + '(%(levelname)1.1s)' + Style.RESET_ALL + ' '
-    tpl += '[' + Fore.BLACK + Style.DIM + Style.BRIGHT + '%(asctime)s' + Fore.RESET + Style.RESET_ALL + ']'
-    tpl += ' ' + Fore.WHITE + Style.DIM + Style.BRIGHT + '%(name)s' + Fore.RESET + Style.RESET_ALL + ' '
-    tpl += Fore.GREEN + Style.BRIGHT + '%(module)s.%(funcName)s()'
-    tpl += Fore.BLACK + Style.DIM + Style.BRIGHT + ':' + Style.RESET_ALL + Fore.CYAN + '%(lineno)d'
-    tpl += Style.RESET_ALL
+    reset = Style.RESET_ALL
+    levelname = (
+        LEVEL_COLORS.get(record.levelname) + Style.BRIGHT +
+        '(%(levelname)1.1s)'
+        + Style.RESET_ALL + ' '
+    )
+    asctime = (
+        '[' + Fore.BLACK + Style.DIM + Style.BRIGHT +
+        '%(asctime)s'
+        + Fore.RESET + Style.RESET_ALL + ']'
+    )
+    name = (
+        ' ' + Fore.WHITE + Style.DIM + Style.BRIGHT +
+        '%(name)s'
+        + Fore.RESET + Style.RESET_ALL + ' '
+    )
+    module_funcName = (
+        Fore.GREEN + Style.BRIGHT +
+        '%(module)s.%(funcName)s()'
+    )
+    lineno = (
+        Fore.BLACK + Style.DIM + Style.BRIGHT + ':' + Style.RESET_ALL +
+        Fore.CYAN + '%(lineno)d'
+    )
+
+    tpl = reset + levelname + asctime + name + module_funcName + lineno + reset
 
     return tpl
 
