@@ -9,6 +9,8 @@ tmuxp.tests
 
 """
 
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 from ..server import Server
 t = Server()
