@@ -1,16 +1,28 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Helper methods for tmuxp unittests.
+
+tmuxp.tests.helpers
+~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import time
 from random import randint
-
+import logging
 try:
     import unittest2 as unittest
 except ImportError:  # Python 2.7
     import unittest
+
 from . import t
 from .. import Server, log, exc
-import logging
+
 logger = logging.getLogger(__name__)
 
 TEST_SESSION_PREFIX = 'tmuxp_'
@@ -66,9 +78,11 @@ class TmuxTestCase(TestCase):
             )
         ]
 
-        # assert session_list == t.sessions
+        while True:
+            TEST_SESSION_NAME = TEST_SESSION_PREFIX + str(randint(0, 9999999))
+            if not t.has_session(TEST_SESSION_NAME):
+                break
 
-        TEST_SESSION_NAME = TEST_SESSION_PREFIX + str(randint(0, 13370))
         try:
             session = t.new_session(
                 session_name=TEST_SESSION_NAME,
@@ -76,10 +90,10 @@ class TmuxTestCase(TestCase):
         except exc.TmuxpException as e:
             raise e
 
-        '''
-        Make sure that tmuxp can :ref:`test_builder_visually` and switches to the
-        newly created session for that testcase.
-        '''
+        """
+        Make sure that tmuxp can :ref:`test_builder_visually` and switches to
+        the newly created session for that testcase.
+        """
         try:
             t.switch_client(session.get('session_id'))
             pass
@@ -88,8 +102,10 @@ class TmuxTestCase(TestCase):
             pass
 
         for old_test_session in old_test_sessions:
-            logger.debug('Old test test session %s found. Killing it.' %
-                        old_test_session)
+            logger.debug(
+                'Old test test session %s found. Killing it.' %
+                old_test_session
+            )
             t.kill_session(old_test_session)
         assert TEST_SESSION_NAME == session.get('session_name')
         assert TEST_SESSION_NAME != 'tmuxp'
