@@ -1,15 +1,28 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Test for tmuxp configuration import, inlining, expanding and export.
+
+tmuxp.tests.test_config
+~~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import os
 import shutil
 import tempfile
+import logging
+
 import kaptan
+
 from .. import config, exc
 from ..util import tmux
 from .helpers import TestCase
 
-import logging
 
 logger = logging.getLogger(__name__)
 TMUXP_DIR = os.path.join(os.path.dirname(__file__), '.tmuxp')
@@ -105,7 +118,9 @@ class ImportExportTest(TestCase):
 
         if os.path.exists(self.tmp_dir):
             for r, d, f in os.walk(self.tmp_dir):
-                for filela in (x for x in f if x.endswith(('.json', '.ini', 'yaml'))):
+                for filela in (
+                    x for x in f if x.endswith(('.json', '.ini', 'yaml'))
+                ):
                     configs.append(os.path.join(
                         self.tmp_dir, filela))
 
@@ -134,23 +149,25 @@ class ExpandTest(TestCase):
     before_config = {
         'session_name': 'sampleconfig',
         'start_directory': '~',
-        'windows': [{
-            'window_name': 'editor',
-            'panes': [
-                {
-                    'shell_command': [
-                        'vim',
-                        'top'
-                    ]
-                },
-                {
-                    'shell_command': ['vim'],
-                },
-                {
-                    'shell_command': 'cowsay "hey"'
-                },
-            ],
-            'layout': 'main-verticle'},
+        'windows': [
+            {
+                'window_name': 'editor',
+                'panes': [
+                    {
+                        'shell_command': [
+                            'vim',
+                            'top'
+                        ]
+                    },
+                    {
+                        'shell_command': ['vim'],
+                    },
+                    {
+                        'shell_command': 'cowsay "hey"'
+                    }
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'window_name': 'logging',
                 'panes': [
@@ -187,7 +204,6 @@ class ExpandTest(TestCase):
                     'pwd'
                 ]
             },
-
             {
                 'panes': [
                     'top'
@@ -264,6 +280,91 @@ class ExpandTest(TestCase):
         test_config = config.expand(self.before_config)
         self.assertDictEqual(test_config, self.after_config)
 
+    def test_no_window_name(self):
+        """Expand shell commands from string to list."""
+
+        unexpanded_yaml = """
+        session_name: sampleconfig
+        start_directory: '~'
+        windows:
+        - window_name: focused window
+          layout: main-horizontal
+          focus: true
+          panes:
+          - shell_command:
+            - cd ~
+          - shell_command:
+            - cd /usr
+            focus: true
+          - shell_command:
+            - cd ~
+            - echo "moo"
+            - top
+        - window_name: window 2
+          panes:
+          - shell_command:
+            - top
+            focus: true
+          - shell_command:
+            - echo "hey"
+          - shell_command:
+            - echo "moo"
+          - window_name: window 3
+          panes:
+          - shell_command: cd /
+            focus: true
+          - pane
+          - pane
+        """
+
+        expanded_yaml = """
+        session_name: sampleconfig
+        start_directory: '~'
+        windows:
+        - window_name: focused window
+          layout: main-horizontal
+          focus: true
+          panes:
+          - shell_command:
+            - cd ~
+          - shell_command:
+            - cd /usr
+            focus: true
+          - shell_command:
+            - cd ~
+            - echo "moo"
+            - top
+        - window_name: window 2
+          panes:
+          - shell_command:
+            - top
+            focus: true
+          - shell_command:
+            - echo "hey"
+          - shell_command:
+            - echo "moo"
+          - window_name: window 3
+          panes:
+          - shell_command:
+            - cd /
+            focus: true
+          - shell_command: []
+          - shell_command: []
+        """
+
+        self.maxDiff = None
+
+        unexpanded_dict = kaptan.Kaptan(handler='yaml'). \
+            import_config(unexpanded_yaml).get()
+
+        expanded_dict = kaptan.Kaptan(handler='yaml'). \
+            import_config(expanded_yaml).get()
+
+        self.assertDictEqual(
+            config.expand(unexpanded_dict),
+            expanded_dict
+        )
+
 
 class InlineTest(TestCase):
 
@@ -334,7 +435,7 @@ class InlineTest(TestCase):
     }
 
     def test_config(self):
-        """:meth:`config.inline()` shell commands list to string where applicable."""
+        """:meth:`config.inline()` shell commands list to string."""
 
         self.maxDiff = None
         test_config = config.inline(self.before_config)
@@ -599,7 +700,10 @@ class ShellCommandBeforeTest(TestCase):
                 'window_name': 'logging',
                 'panes': [
                     {
-                        'shell_command': ['rbenv local 2.0.0-p0', 'tail -F /var/log/syslog'],
+                        'shell_command': [
+                            'rbenv local 2.0.0-p0',
+                            'tail -F /var/log/syslog'
+                        ],
                     },
                     {
                         'shell_command': ['rbenv local 2.0.0-p0']
@@ -648,6 +752,75 @@ class ShellCommandBeforeTest(TestCase):
         self.assertDictEqual(test_config, self.config_after)
 
 
+class ShellCommandBeforeSession(TestCase):
+
+    def test_in_session_scope(self):
+
+        yaml_config = """
+        shell_command_before:
+          - 'echo "hi"'
+        session_name: 'test'
+        windows:
+        - window_name: editor
+          panes:
+          - shell_command:
+            - vim
+            - :Ex
+          - pane
+          - cd /usr
+        - window_name: logging
+          panes:
+          - shell_command:
+            -
+          - shell_command:
+            - top
+            - emacs
+        """
+
+        yaml_final_config = """
+        shell_command_before:
+          - 'echo "hi"'
+        session_name: 'test'
+        windows:
+        - window_name: editor
+          panes:
+          - shell_command:
+            - 'echo "hi"'
+            - vim
+            - :Ex
+          - shell_command:
+            - 'echo "hi"'
+          - shell_command:
+            - 'echo "hi"'
+            - cd /usr
+        - window_name: logging
+          panes:
+          - shell_command:
+            - 'echo "hi"'
+          - shell_command:
+            - 'echo "hi"'
+            - top
+            - emacs
+        """
+
+        self.maxDiff = None
+
+        sconfig = kaptan.Kaptan(handler='yaml')
+        sconfig = sconfig.import_config(yaml_config).get()
+
+        config.validate_schema(sconfig)
+
+        self.assertDictEqual(config.expand(sconfig), sconfig)
+
+        self.assertDictEqual(
+            config.expand(config.trickle(sconfig)),
+            self.yaml_to_dict(yaml_final_config)
+        )
+
+    def yaml_to_dict(self, yaml):
+        return kaptan.Kaptan(handler='yaml').import_config(yaml).get()
+
+
 class TrickleRelativeStartDirectory(TestCase):
 
     config_expanded = {  # shell_command_before is string in some areas
@@ -731,7 +904,6 @@ class ConfigBlankPanes(TestCase):
         'windows': [
             {
                 'window_name': 'Blank pane test',
-                'layout': 'tiled',
                 'panes': [
                     {
                         'shell_command': [],
@@ -741,7 +913,12 @@ class ConfigBlankPanes(TestCase):
                     },
                     {
                         'shell_command': [],
-                    },
+                    }
+                ]
+            },
+            {
+                'window_name': 'More blank panes',
+                'panes': [
                     {
                         'shell_command': [],
                     },
@@ -857,7 +1034,9 @@ class ConfigConsistency(TestCase):
         sconfig = kaptan.Kaptan(handler='yaml')
         sconfig = sconfig.import_config(yaml_config).get()
 
-        with self.assertRaisesRegexp(exc.ConfigError, 'requires "session_name"'):
+        with self.assertRaisesRegexp(
+            exc.ConfigError, 'requires "session_name"'
+        ):
             config.validate_schema(sconfig)
 
     def test_no_windows(self):
