@@ -1,14 +1,26 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Test for tmuxp teamocil configuration..
+
+tmuxp.tests.test_config_teamocil
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import os
+import logging
+
 import kaptan
+
 from .. import config, exc
 from ..util import tmux
 from .helpers import TestCase
 
-import logging
-
 logger = logging.getLogger(__name__)
 TMUXP_DIR = os.path.join(os.path.dirname(__file__), '.tmuxp')
 
@@ -83,13 +95,6 @@ class TeamocilTest(TestCase):
             )
         )
 
-    def test_config_to_yaml(self):
-        """teamocil yaml to tmuxp yaml config
-
-        use validate_schema to assert against
-        """
-        pass
-
 
 class Teamocil2Test(TestCase):
 
@@ -210,7 +215,10 @@ class Teamocil3Test(TestCase):
                 'layout': 'even-vertical',
                 'start_directory': "~/Projects/foo-www",
                 'shell_command_before': 'rbenv local 2.0.0-p0',
-                'shell_command_after': 'echo \'I am done initializing this pane.\'',
+                'shell_command_after': (
+                    'echo '
+                    '\'I am done initializing this pane.\''
+                ),
                 'panes': [
                     {
                         'shell_command': 'git status'
@@ -306,11 +314,12 @@ class Teamocil4Test(TestCase):
 
 class TeamocilLayoutsTest(TestCase):
 
-    """
+    """Import configurations from teamocil's <fixtures/layout.yml>.
 
     https://github.com/remiprev/teamocil/blob/master/spec/fixtures/layouts.yml
 
     LICENSE: https://github.com/remiprev/teamocil/blob/master/LICENSE
+
     """
 
     teamocil_yaml = """\
