@@ -1,12 +1,24 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Test for tmuxp TmuxRelationalObject and TmuxMappingObject.
+
+tmuxp.tests.test_tmuxobject
+~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import random
+import logging
+
 from .. import Pane, Window, Session
 from . import t
-from .helpers import TmuxTestCase
 
-import logging
+from .helpers import TmuxTestCase, TEST_SESSION_PREFIX
 
 logger = logging.getLogger(__name__)
 
@@ -16,15 +28,18 @@ class TmuxObjectTest(TmuxTestCase):
     """Test the :class:`TmuxRelationalObject` base class object."""
 
     def test_findWhere(self):
-        """findWhere."""
+        """Test that findWhere() retrieves single matching object."""
         self.maxDiff = None
         # server.findWhere
         for session in t.sessions:
             session_id = session.get('session_id')
 
             self.assertEqual(t.findWhere({'session_id': session_id}), session)
-            self.assertIsInstance(t.findWhere({
-                                  'session_id': session_id}), Session)
+            self.assertIsInstance(
+                t.findWhere({
+                    'session_id': session_id
+                }), Session
+            )
 
             # session.findWhere
             for window in session.windows:
@@ -46,6 +61,21 @@ class TmuxObjectTest(TmuxTestCase):
                     self.assertIsInstance(window.findWhere(
                         {'pane_id': pane_id}), Pane)
 
+    def test_findWhere_None(self):
+        """.findWhere returns None if no results found."""
+
+        while True:
+            nonexistant_session = TEST_SESSION_PREFIX + str(
+                random.randint(0, 9999)
+            )
+
+            if not t.has_session(nonexistant_session):
+                break
+
+        self.assertIsNone(t.findWhere({
+            'session_name': nonexistant_session
+        }))
+
     def test_findWhere_multiple_attrs(self):
         """.findWhere returns objects with multiple attributes."""
 
@@ -87,7 +117,7 @@ class TmuxObjectTest(TmuxTestCase):
                     self.assertIsInstance(find_where, Pane)
 
     def test_where(self):
-        """.where"""
+        """Test self.where() returns matching objects."""
 
         window = self.session.attached_window()
         window.split_window()  # create second pane
@@ -136,7 +166,7 @@ class TmuxObjectTest(TmuxTestCase):
                     self.assertIsInstance(where[0], Pane)
 
     def test_getById(self):
-        """.getById"""
+        """Test self.getById() retrieves child object."""
 
         window = self.session.attached_window()
 
